# -*- coding: utf-8 -*-
# Copyright © 2005 Lateef Alabi-Oki
#
# This file is part of Scribes.
#
# Scribes is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Scribes is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Scribes; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

"""
This module documents a class that implements the database for the
text editor's bookmark browser.

@author: Lateef Alabi-Oki
@organization: The Scribes Project
@copyright: Copyright © 2005 Lateef Alabi-Oki
@license: GNU GPLv2 or Later
@contact: mystilleef@gmail.com
"""

from gtk import ListStore

class BookmarkBrowserModel(ListStore):
	"""
	This class implements an object that represents the data structure
	for the bookmark browser.
	"""

	def __init__(self, manager):
		"""
		Initialize the data model object.

		@param self: Reference to the BookmarkBrowserModel instance.
		@type self: A BookmarkBrowserModel object.

		@param manager: The text editor's bookmark manager.
		@type manager: A BookmarkManager object.
		"""
 		ListStore.__init__(self, int, str, "gboolean")
 		self.__init_attributes(manager)
		self.browser.connect("map-event", self.__model_map_event_cb) 

 	def __init_attributes(self, bookmark_view):
 		"""
 		Initialize the model's data attributes.

 		@param self: Reference to the BookmarkBrowserModel instance.
 		@type self: A BookmarkBrowserModel object.

		@param manager: The text editor's bookmark manager.
		@type manager: A BookmarkManager object.
 		"""
 		self.view = bookmark_view
 		self.manager = bookmark_view.manager
 		self.editor = bookmark_view.editor
 		self.textbuffer = self.editor.textbuffer
 		self.browser = bookmark_view.browser 
 		self.bookmarked_lines = [] 
 		return

	def __populate_model(self):
		"""
		Populate the model.

		@param self: Reference to the BookmarkBrowserModel instance.
		@type self: A BookmarkBrowserModel object.
		"""
		lines = self.manager.get_bookmarked_lines()
		from lines import get_text_on_line
		value = False
		bookmarked_lines = [] 
		for line in lines:
			text = get_text_on_line(self.textbuffer, line)
			text = text.strip(" ")
			text = text.strip("\t")
			bookmarked_lines.append((line, text))
		if self.bookmarked_lines == bookmarked_lines: 
			return 
		self.bookmarked_lines = bookmarked_lines
		recently_bookmarked_line = self.manager.bookmark_list[-1].get_line()
		self.clear() 
		for line, text in self.bookmarked_lines: 
			if line == recently_bookmarked_line:
				value = True
			self.append([(line+1), text, value])
			value = False
		return

	def __model_map_event_cb(self, dialog, event): 
		self.__populate_model()
		self.view.grab_focus()
		return True  
