# -*- coding: utf-8 -*-
# Copyright © 2005 Lateef Alabi-Oki
#
# This file is part of Scribes.
#
# Scribes is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Scribes is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Scribes; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

"""
This module documents a class that manages the text editor's completion
window components.

@author: Lateef Alabi-Oki
@organization: The Scribes Project
@copyright: Copyright © 2005 Lateef Alabi-Oki
@license: GNU GPLv2 or Later
@contact: mystilleef@gmail.com
"""

from gobject import GObject, SIGNAL_RUN_LAST, TYPE_NONE, type_register

class CompletionManager(GObject):
	"""
	This class creates the completion window object and its components.
	The class manages synchronizes communication between the completion
	window's components.
	"""

	__gsignals__ = {
		"show-completion-window": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
		"hide-completion-window": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
	}

	def __init__(self, completion):
		"""
		Initialize the manager objet.

		@param self: Reference to the CompletionManager instance.
		@type self: A CompletionManager object.

		@param completion: A word completion object.
		@type completion: A WordCompletion object.
		"""
		GObject.__init__(self)
		type_register(type(self))
		self.__init_attributes(completion)
		self.__create_widgets()
		self.__arrange_widgets()

	def __init_attributes(self, completion):
		"""
		Initialize the manager objet.

		@param self: Reference to the CompletionManager instance.
		@type self: A CompletionManager object.

		@param completion: A word completion object.
		@type completion: A WordCompletion object.
		"""
		self.completion = completion
		self.window = None
		self.view = None
		self.scrolledwindow = None
		self.editor = completion.editor
		return

	def __create_widgets(self):
		"""
		Create graphic user interface components for completion system.

		@param self: Reference to the CompletionManager instance.
		@type self: A CompletionManager object.
		"""
		from completionview import CompletionView
		self.view = CompletionView(self)
		from completionswindow import CompletionScrolledWindow
		self.scrolledwindow = CompletionScrolledWindow(self.view)
		from completionwindow import CompletionWindow
		self.window = CompletionWindow(self)
		return

 	def __arrange_widgets(self):
 		"""
 		Arrange the graphic user interface components of the completion
 		system.

 		@param self: Reference to the CompletionManager instance.
 		@type self: A CompletionManager object.
 		"""
 		self.scrolledwindow.add(self.view)
 		self.window.add(self.scrolledwindow)
 		return
