# -*- coding: utf-8 -*-
# Copyright © 2005 Lateef Alabi-Oki
#
# This file is part of Scribes.
#
# Scribes is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Scribes is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Scribes; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

"""
This module documents the the scrolled window object for the text editor's
completion window.

@author: Lateef Alabi-Oki
@organization: The Scribes Project
@copyright: Copyright © 2005 Lateef Alabi-Oki
@license: GNU GPLv2 or Later
@contact: mystilleef@gmail.com
"""

from gobject import SIGNAL_RUN_LAST, TYPE_NONE
from gtk import ScrolledWindow

class CompletionScrolledWindow(ScrolledWindow):
	"""
	Scrolled window for the text editor's completion window.
	"""

	__gsignals__ = {
		"policy-determined": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
	}

	def __init__(self, completion_view):
		"""
		Initialize the scrolled window container object.

		@param self: Reference to the CompletionScrolledWindow instance.
		@type self: A CompletionScrolledWindow object.

		@param completion_view: The completion window's view.
		@type completion_view: A CompletionView object.
		"""
		ScrolledWindow.__init__(self)
		self.__init_attributes(completion_view)
		self.__set_properties()
		self.view.connect("populated-model", self.__scroll_populated_window_cb)

	def __init_attributes(self, completion_view):
		"""
		Initialize the scrolled window container object.

		@param self: Reference to the CompletionScrolledWindow instance.
		@type self: A CompletionScrolledWindow object.

		@param completion_view: The completion window's view.
		@type completion_view: A CompletionView object.
		"""
		self.view = completion_view
		return

	def __set_properties(self):
		"""
		Define the scrolled window's default properties.

		@param self: Reference to the CompletionScrolledWindow instance.
		@type self: A CompletionScrolledWindow object.
		"""
		from gtk import POLICY_NEVER, POLICY_ALWAYS
		self.set_policy(POLICY_NEVER, POLICY_NEVER)
		self.set_property("border-width", 2)
		return

	def __scroll_populated_window_cb(self, view):
		"""
		Handles callback when the "populated-model" signal is emitted.

		This function determines what policy to use when showing the
		scrolled window depending on the size of the completion window's
		view.

		@param self: Reference to the CompletionScrolledWindow instance.
		@type self: A CompletionScrolledWindow object.

		@param view: The completion window's view.
		@type view: A CompletionView object.
		"""
		from gtk import POLICY_NEVER, POLICY_ALWAYS
		width, height = view.size_request()
		if width <= 200 and height <= 200:
			self.set_policy(POLICY_NEVER, POLICY_NEVER)
		elif width >= 200 and height <= 200:
			self.set_policy(POLICY_NEVER, POLICY_NEVER)

		elif width <= 200 and height >= 200:
			self.set_policy(POLICY_NEVER, POLICY_ALWAYS)
		else:
			self.set_policy(POLICY_NEVER, POLICY_ALWAYS)
		self.emit("policy-determined")
		return
