# -*- coding: utf-8 -*-
# Copyright © 2005 Lateef Alabi-Oki
#
# This file is part of Scribes.
#
# Scribes is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Scribes is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Scribes; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

class DuplicateURI(object):
	"""
	This class checks for duplicate URIs.
	"""

	def __init__(self, file_uri, editor=None):
		"""
		Initialize the object.

		@param self: Reference to the DuplicateURI instance.
		@type self: A DuplicateURI object.
		"""
		from gtk import threads_enter, threads_leave
		self.__init_attributes(file_uri, editor)
		self.__get_text_editor_service()
		threads_enter()
		self.__get_open_uris()
		threads_leave()

	def __init_attributes(self, file_uri, editor):
		self.__open_uris = []
		self.__file_uri = file_uri
		self.__service_list = []
		self.__count = 0
		self.__editor = editor
		return

	def __get_text_editor_service(self):
		from info import dbus_iface
		# Look for services owned by the text editor.
		for service in dbus_iface.ListNames():
			if service.startswith("net.sourceforge.Scribes"):
				if self.__editor:
					if service == self.__editor.dbus_name:
						continue
				self.__service_list.append(service)
		return

	def __get_open_uris(self):
		from info import session_bus
		if self.__service_list:
			for service in self.__service_list:
				proxy_obj = session_bus.get_object(service, "/net/sourceforge/Scribes")
				proxy_obj.get_uri(dbus_interface="net.sourceforge.ScribesIFace",
						reply_handler=self.__reply_handler_cb,
						error_handler=self.__error_handler_cb)
		else:
			from gobject import timeout_add
			timeout_add(7, self.__load_file)
		return

	def __reply_handler_cb(self, uri):
		self.__open_uris.append(uri)
		self.__count += 1
		if self.__count == len(self.__service_list):
			from gobject import timeout_add
			timeout_add(7, self.__load_file)
		return

	def __error_handler_cb(self, error):
		print "Dang: ", error
		return

	def __load_file(self):
		if self.__file_uri in self.__open_uris:
			from test import object
			object.focus_window(self.__file_uri)
			raise SystemExit
		else:
			from thread import start_new_thread
			if self.__editor:
				from loader import Loader
				from gobject import timeout_add
				#timeout_add(7, Loader, self.__editor, self.__file_uri)
				start_new_thread(Loader, (self.__editor, self.__file_uri))
				#Loader(self.__editor, self.__file_uri)
			else:
				from editor import Editor
				Editor(True, self.__file_uri)
		return False
