# -*- coding: utf-8 -*-
# Copyright © 2005 Lateef Alabi-Oki
#
# This file is part of Scribes.
#
# Scribes is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Scribes is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Scribes; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

"""
This modules documents a class that creates a trigger to show the text
editor's goto bar.

@author: Lateef Alabi-Oki
@organization: The Scribes Project
@copyright: Copyright © 2005 Lateef Alabi-Oki
@license: GNU GPLv2 or Later
@contact: mystilleef@gmail.com
"""

class GotoBarTrigger(object):
	"""
	This class implements an object that shows the goto bar.
	"""

	def __init__(self, editor):
		"""
		Initialize the trigger object.

		@param self: Reference to the GotoBarTrigger instance.
		@type self: A GotoBarTrigger object.

		@param editor: Reference to the text editor.
		@type editor: An Editor object.
		"""
		self.__init_attributes(editor)
		self.__create_trigger()
		self.__trigger.connect("activate", self.__show_gotobar_cb)

	def __init_attributes(self, editor):
		"""
		Initialize data attributes.

		@param self: Reference to the GotoBarTrigger instance.
		@type self: A GotoBarTrigger object.

		@param editor: Reference to the text editor.
		@type editor: An Editor object.
		"""
		self.__editor = editor
		self.__trigger = None
		self.__gotobar = None
		return

	def __create_trigger(self):
		"""
		Create trigger.

		@param self: Reference to the GotoBarTrigger instance.
		@type self: A GotoBarTrigger object.
		"""
		# Trigger to show the goto bar.
		from trigger import Trigger
		self.__trigger = Trigger("show_gotobar")
		self.__editor.triggermanager.add_trigger(self.__trigger, "control - i")
		return

	def __show_gotobar_cb(self, trigger):
		"""
		Handles callback when the "activate" signal is emitted.

		@param self: Reference to the GotoBarTrigger instance.
		@type self: A GotoBarTrigger object.

		@param trigger: An object to show the goto bar.
		@type trigger: A Trigger object.
		"""
		try:
			self.__gotobar.show_bar()
		except AttributeError:
			from gotobar import ScribesGotoBar
			self.__gotobar = ScribesGotoBar(self.__editor)
			self.__gotobar.show_bar()
		return
