# -*- coding: utf-8 -*-
# Copyright (C) 2005 Lateef Alabi-Oki
#
# This file is part of Scribes.
#
# Scribes is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Scribes is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Scribes; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

"""
Translatable strings for Scribes.

This modules contains user visible string eligible for translation. The strings
are defined by a unique identifier or format:

	msgXXXX = u"string eligible for translation"

XXXX is a number between 0001 and 9999.

@author: Lateef Alabi-Oki
@organiation: The Scribes Project
@copyright: Copyright © 2005 Lateef Alabi-Oki
@license: GNU GPLv2 or Later
@contact: mystilleef@gmail.com
"""

from locale import setlocale, LC_ALL, Error, getpreferredencoding
from locale import getdefaultlocale
from gettext import bindtextdomain, textdomain, gettext, bind_textdomain_codeset

def find_locale_folder():
	"""
	Search for Scribes' data folder

	@return: path Scribes' data folder
	@rtype: string
	"""
	from info import scribes_data_path
	from os import path
	locale_folder = path.join(scribes_data_path, "locale")
	return locale_folder

try:
	locale = getdefaultlocale()[0]
	setlocale(LC_ALL, locale)
except Error:
	pass

locale_folder = find_locale_folder()
if not locale_folder:
	locale_folder = "/usr/share/locale"
bindtextdomain("scribes", locale_folder)
textdomain("scribes")
bind_textdomain_codeset("scribes", "utf-8")
_ = gettext

# From module about.py
msg0001 = _("Scribes is a text editor for GNOME.")#.decode(encoding).encode("utf-8")

# From module accelerators.py
msg0002 = _("Cannot undo action")#.decode(encoding).encode("utf-8")
msg0003 = _("Cannot redo action")#.decode(encoding).encode("utf-8")

# From module lines.py
msg0004 = _("Deleted line %d")#.decode(encoding).encode("utf-8")
msg0005 = _("Joined line %d to line %d")#.decode(encoding).encode("utf-8")
msg0006 = _("No more lines to join")#.decode(encoding).encode("utf-8")

# From module select.py
msg0007 = _("Selected word")#.decode(encoding).encode("utf-8")
msg0008 = _("No word to select")#.decode(encoding).encode("utf-8")
msg0009 = _("No text to select on line %d")#.decode(encoding).encode("utf-8")
msg0010 = _("Selected line %d")#.decode(encoding).encode("utf-8")
msg0011 = _("Selected paragraph")#.decode(encoding).encode("utf-8")
msg0012 = _("No paragraph to select")#.decode(encoding).encode("utf-8")
msg0013 = _("Selected sentence")#.decode(encoding).encode("utf-8")
msg0014 = _("No sentence to select")#.decode(encoding).encode("utf-8")

# From module case.py
msg0015 = _("No selection to change case")#.decode(encoding).encode("utf-8")
msg0016 = _("Selected text is already uppercase")#.decode(encoding).encode("utf-8")
msg0017 = _("Changed selected text from lowercase to uppercase")#.decode(encoding).encode("utf-8")
msg0018 = _("Selected text is already lowercase")#.decode(encoding).encode("utf-8")
msg0019 = _("Changed selected text from uppercase to lowercase")#.decode(encoding).encode("utf-8")

# From module bracket.py
msg0020 = _("Found matching bracket on line %d")#.decode(encoding).encode("utf-8")
msg0021 = _("No matching bracket found")#.decode(encoding).encode("utf-8")

# From module editor_ng.py
msg0022 = _("Disabled spellchecking")#.decode(encoding).encode("utf-8")
msg0023 = _("Enabled spellchecking")#.decode(encoding).encode("utf-8")
msg0024 = _("Leave Fullscreen")#.decode(encoding).encode("utf-8")

# From module editor_ng.py, fileloader.py, timeout.py
msg0025 = _("Unsaved Document")#.decode(encoding).encode("utf-8")

# From module filechooser.py
msg0026 = _("Open Document")#.decode(encoding).encode("utf-8")
msg0027 = _("All Documents")#.decode(encoding).encode("utf-8")
msg0028 = _("Python Documents")#.decode(encoding).encode("utf-8")
msg0029 = _("Text Documents")#.decode(encoding).encode("utf-8")

# From module fileloader.py
msg0030 = _('Loaded file "%s"')#.decode(encoding).encode("utf-8")
msg0031 = _("The encoding of the file you are trying to open could not be \
determined. Try opening the file with another encoding.")#.decode(encoding).encode("utf-8")
msg0032 = _("Loading file please wait...")#.decode(encoding).encode("utf-8")
msg0033 = _("An error occurred while openning the file. Please file a bug \
report at http://scribes.sourceforge.net")#.decode(encoding).encode("utf-8")

# From module fileloader.py, savechooser.py
msg0034 = _(" <READONLY>")#.decode(encoding).encode("utf-8")

# From module fileloader.py
msg0035 = _("You do not have permission to view this file.")#.decode(encoding).encode("utf-8")
msg0036 = _("The file you are trying to open is not a text file.")#.decode(encoding).encode("utf-8")
msg0037 = _("The file you are trying to open does not exist.")#.decode(encoding).encode("utf-8")

# From module main.py
msg0038 = _("Unrecognized option: '%s'")#.decode(encoding).encode("utf-8")
msg0039 = _("Try 'scribes --help' for more information")#.decode(encoding).encode("utf-8")
msg0040 = _("Scribes only supports using one option at a time")#.decode(encoding).encode("utf-8")
msg0041 = _("scribes: %s takes no arguments")#.decode(encoding).encode("utf-8")
msg0042 = _("Scribes version %s")#.decode(encoding).encode("utf-8")
msg0043 = _("%s does not exist")#.decode(encoding).encode("utf-8")

# From module timeout.py
msg0044 = _('The file "%s" is open in readonly mode')#.decode(encoding).encode("utf-8")
msg0045 = _('The file "%s" is open')#.decode(encoding).encode("utf-8")

# From modules findbar.py
msg0046 = _("No match found")#.decode(encoding).encode("utf-8")
msg0047 = _("Found %d match")#.decode(encoding).encode("utf-8")
msg0048 = _("Found %d matches")#.decode(encoding).encode("utf-8")
msg0049 = _("_Search for:    ")#.decode(encoding).encode("utf-8")
msg0050 = _("_Search for:")#.decode(encoding).encode("utf-8")
msg0051 = _("_Previous")#.decode(encoding).encode("utf-8")
msg0052 = _("_Next")#.decode(encoding).encode("utf-8")
msg0053 = _("Match _case")#.decode(encoding).encode("utf-8")
msg0054 = _("Match _word")#.decode(encoding).encode("utf-8")

# From modules gotobar.py
msg0055 = _("Line number:")#.decode(encoding).encode("utf-8")
msg0056 = _(" of %d")#.decode(encoding).encode("utf-8")

# From module help.py
msg0057 = _("Launching help browser")#.decode(encoding).encode("utf-8")

# From module indent.py
msg0058 = _("No indentation selection found")#.decode(encoding).encode("utf-8")
msg0059 = _("Selection indented")#.decode(encoding).encode("utf-8")
msg0060 = _("Unindentation is not possible")#.decode(encoding).encode("utf-8")
msg0061 = _("Selection unindented")#.decode(encoding).encode("utf-8")

# From module modes.py
msg0062 = _("loading...")#.decode(encoding).encode("utf-8")

# From module preferences.py
msg0063 = _("<b>Font</b>")#.decode(encoding).encode("utf-8")
msg0064 = _("Editor _font: ")#.decode(encoding).encode("utf-8")
msg0065 = _("<b>Tab Stops</b>")#.decode(encoding).encode("utf-8")
msg0066 = _("_Tab width: ")#.decode(encoding).encode("utf-8")
msg0067 = _("<b>Text Wrapping</b>")#.decode(encoding).encode("utf-8")
msg0068 = _("Enable text _wrapping")#.decode(encoding).encode("utf-8")
msg0069 = _("<b>Right Margin</b>")#.decode(encoding).encode("utf-8")
msg0070 = _("Display right _margin")#.decode(encoding).encode("utf-8")
msg0071 = _("_Right margin position: ")#.decode(encoding).encode("utf-8")
msg0072 = _("<b>Spell Checking</b>")#.decode(encoding).encode("utf-8")
msg0073 = _("_Enable spell checking")#.decode(encoding).encode("utf-8")

# From modules printing.py
msg0074 = _("Print Preview")#.decode(encoding).encode("utf-8")
msg0075 = _("File: ")#.decode(encoding).encode("utf-8")
msg0076 = _("Print Document")#.decode(encoding).encode("utf-8")

# From module replace.py
msg0077 = _('"%s" has been replaced with "%s"')#.decode(encoding).encode("utf-8")
msg0078 = _('Replaced all occurrences of "%s" with "%s"')#.decode(encoding).encode("utf-8")
msg0079 = _("Replac_e with:")#.decode(encoding).encode("utf-8")
msg0080 = _("_Replace")#.decode(encoding).encode("utf-8")
msg0081 = _("Replace _All")#.decode(encoding).encode("utf-8")

# From module savechooser.py
msg0082 = _("Save Document")#.decode(encoding).encode("utf-8")

# From module savefile.py
msg0083 = _("An error occurred while saving this file.")#.decode(encoding).encode("utf-8")
msg0084 = _('An error occurred while decoding your file. Please file a bug \
report at "http://openusability.org/forum/?group_id=141"')#.decode(encoding).encode("utf-8")
msg0085 = _('Saved "%s"')#.decode(encoding).encode("utf-8")

# From module textview.py
msg0086 = _("Shift _Right")#.decode(encoding).encode("utf-8")
msg0087 = _("Shift _Left")#.decode(encoding).encode("utf-8")
msg0088 = _("_Find Matching Bracket")#.decode(encoding).encode("utf-8")
msg0089 = _("Copied selected text")#.decode(encoding).encode("utf-8")
msg0090 = _("No selection to copy")#.decode(encoding).encode("utf-8")
msg0091 = _("Cut selected text")#.decode(encoding).encode("utf-8")
msg0092 = _(u"No selection to cut")#.decode(encoding).encode("utf-8")
msg0093 = _("Pasted copied text")#.decode(encoding).encode("utf-8")
msg0094 = _("No text content in the clipboard")#.decode(encoding).encode("utf-8")

# From module timeout.py
msg0095 = _("%d%% complete")#.decode(encoding).encode("utf-8")
msg0096 = _("completed")#.decode(encoding).encode("utf-8")

# From module tooltips.py
msg0097 = _("Open a new window")#.decode(encoding).encode("utf-8")
msg0098 = _("Open a file")#.decode(encoding).encode("utf-8")
msg0099 = _("Rename the current file")#.decode(encoding).encode("utf-8")
msg0100 = _("Print the current file")#.decode(encoding).encode("utf-8")
msg0101 = _("Undo last action")#.decode(encoding).encode("utf-8")
msg0102 = _("Redo undone action")#.decode(encoding).encode("utf-8")
msg0103 = _("Search for text")#.decode(encoding).encode("utf-8")
msg0104 = _("Search for and replace text")#.decode(encoding).encode("utf-8")
msg0105 = _("Go to a specific line")#.decode(encoding).encode("utf-8")
msg0106 = _("Configure the editor")#.decode(encoding).encode("utf-8")
msg0107 = _("Launch the help browser")#.decode(encoding).encode("utf-8")
msg0108 = _("Search for previous occurrence of the string")#.decode(encoding).encode("utf-8")
msg0109 = _("Search for next occurrence of the string")#.decode(encoding).encode("utf-8")
msg0110 = _("Find occurrences of the string that match upper and lower cases \
only")#.decode(encoding).encode("utf-8")
msg0111 = _("Find occurrences of the string that match the entire word only")#.decode(encoding).encode("utf-8")
msg0112 = _("Type in the text you want to search for")#.decode(encoding).encode("utf-8")
msg0113 = _("Type in the text you want to replace with")#.decode(encoding).encode("utf-8")
msg0114 = _("Replace the selected found match")#.decode(encoding).encode("utf-8")
msg0115 = _("Replace all found matches")#.decode(encoding).encode("utf-8")
msg0116 = _("Click to specify the font type, style, and size to use for text.")#.decode(encoding).encode("utf-8")
msg0117 = _("Click to specify the width of the space that is inserted when \
you press the Tab key.")#.decode(encoding).encode("utf-8")
msg0118 = _("Select to wrap text onto the next line when you reach the \
text window boundary.")#.decode(encoding).encode("utf-8")
msg0119 = _("Select to display a vertical line that indicates the right \
margin.")#.decode(encoding).encode("utf-8")
msg0120 = _("Click to specify the location of the vertical line.")#.decode(encoding).encode("utf-8")
msg0121 = _("Select to enable spell checking")#.decode(encoding).encode("utf-8")

# From module undo_redo.py
msg0122 = _("Undid last action")#.decode(encoding).encode("utf-8")
msg0123 = _("Redid undone action")#.decode(encoding).encode("utf-8")

# From module usage.py
msg0124 = _("A text editor for GNOME.")#.decode(encoding).encode("utf-8")
msg0125 = _("usage: scribes [OPTION] [FILE] [...]")#.decode(encoding).encode("utf-8")
msg0126 = _("Options:")#.decode(encoding).encode("utf-8")
msg0127 = _("display this help screen")#.decode(encoding).encode("utf-8")
msg0128 = _("output version information of Scribes")#.decode(encoding).encode("utf-8")
msg0129 = _("create a new file and open the file with Scribes")#.decode(encoding).encode("utf-8")
msg0130 = _("open file in readonly mode")#.decode(encoding).encode("utf-8")

# From module utility.py
msg0131 = _("Could not find Scribes' data folder")#.decode(encoding).encode("utf-8")

# From preferences.py
msg0132 = _("Preferences")#.decode(encoding).encode("utf-8")

# From error.py
msg0133 = _("error")#.decode(encoding).encode("utf-8")

# From module indent.py
msg0134 = _("No spaces were found at end of line")#.decode(encoding).encode("utf-8")
msg0135 = _("Removed spaces at end of line %d")#.decode(encoding).encode("utf-8")

# From module lines.py
msg0136 = _("Freed line %d")#.decode(encoding).encode("utf-8")
msg0137 = _("Deleted text from cursor to end of line %d")#.decode(encoding).encode("utf-8")
msg0138 = _("Cursor is already at the end of line")#.decode(encoding).encode("utf-8")
msg0139 = _("Deleted text from cursor to beginning of line %d")#.decode(encoding).encode("utf-8")
msg0140 = _("Cursor is already at the beginning of line")#.decode(encoding).encode("utf-8")

# From module indent.py
msg0141 = _("No spaces were found at beginning of line")#.decode(encoding).encode("utf-8")
msg0142 = _("Removed spaces at beginning of line %d")#.decode(encoding).encode("utf-8")
msg0143 = _("Removed spaces at beginning of selected lines")#.decode(encoding).encode("utf-8")
msg0144 = _("Removed spaces at end of selected lines")#.decode(encoding).encode("utf-8")

# From module actions.py
msg0145 = _("Cannot perform operation in readonly mode")#.decode(encoding).encode("utf-8")

# From module indent.py
msg0146 = _("Indented line %d")#.decode(encoding).encode("utf-8")
msg0147 = _("Unindented line %d")#.decode(encoding).encode("utf-8")
msg0148 = _("No selected lines can be indented")#.decode(encoding).encode("utf-8")

# From module case.py
msg0149 = _("Swapped the case of selected text")#.decode(encoding).encode("utf-8")
msg0150 = _("Capitalized selected text")#.decode(encoding).encode("utf-8")
msg0151 = _("Selected text is already capitalized")#.decode(encoding).encode("utf-8")

# From module savefile.py
msg0152 = _("An error occurred while encoding your file. Try saving your \
file using another character encoding, preferably UTF-8.")#.decode(encoding).encode("utf-8")

# From module fileloader.py
msg0153 = _("An encoding error occurred. Please file a bug report at \
http://openusability.org/forum/?group_id=141")#.decode(encoding).encode("utf-8")

# From brackets.py
msg0154 = _("Pair character completion occurred")#.decode(encoding).encode("utf-8")

# From autocomplete.py
msg0155 = _("Word completion occurred")#.decode(encoding).encode("utf-8")

# From brackets.py
msg0156 = _("Removed pair character completion")#.decode(encoding).encode("utf-8")

# From encoding.py
msg0157 = _("Character _Encoding: ")#.decode(encoding).encode("utf-8")
msg0158 = _("Add or Remove Encoding ...")#.decode(encoding).encode("utf-8")
msg0159 = _("Recommended (UTF-8)")#.decode(encoding).encode("utf-8")
msg0160 = _("Add or Remove Character Encoding")#.decode(encoding).encode("utf-8")
msg0161 = _("Language and Region")#.decode(encoding).encode("utf-8")
msg0162 = _("Character Encoding")#.decode(encoding).encode("utf-8")
msg0163 = _("Select")#.decode(encoding).encode("utf-8")

# From bookmark.py
msg0164 = _("Line %d is already bookmarked")#.decode(encoding).encode("utf-8")
msg0165 = _("Bookmarked line %d")#.decode(encoding).encode("utf-8")
msg0166 = _("No bookmark on line %d to remove")#.decode(encoding).encode("utf-8")
msg0167 = _("Removed bookmark on line %d")#.decode(encoding).encode("utf-8")
msg0168 = _("No bookmarks found to remove")#.decode(encoding).encode("utf-8")
msg0169 = _("Removed all bookmarks")#.decode(encoding).encode("utf-8")
msg0170 = _("No next bookmark to move to")#.decode(encoding).encode("utf-8")
msg0171 = _("Moved to bookmark on line %d")#.decode(encoding).encode("utf-8")
msg0172 = _("No previous bookmark to move to")#.decode(encoding).encode("utf-8")

# From filechooser.py, savechooser.py
msg0173 = _("Select character _encoding")#.decode(encoding).encode("utf-8")

# From indent.py
msg0174 = _("Replaced tabs with spaces on line %d")#.decode(encoding).encode("utf-8")
msg0175 = _("Replacing tabs please wait...")#.decode(encoding).encode("utf-8")
msg0176 = _("No tabs found on line %d")#.decode(encoding).encode("utf-8")
msg0177 = _("No tabs found in selected text")#.decode(encoding).encode("utf-8")
msg0178 = _("Removing spaces please wait...")#.decode(encoding).encode("utf-8")
msg0179 = _("Indenting please wait...")#.decode(encoding).encode("utf-8")

# From gotobar.py
msg0180 = _("Move cursor to a specific line")#.decode(encoding).encode("utf-8")
msg0181 = _("Moved cursor to line %d")#.decode(encoding).encode("utf-8")
msg0182 = _("Closed goto line bar")#.decode(encoding).encode("utf-8")

# From findbar.py
msg0183 = _("Search for text")#.decode(encoding).encode("utf-8")
msg0184 = _("Closed search bar")#.decode(encoding).encode("utf-8")

# From replacebar.py
msg0185 = _("Search for and replace text")#.decode(encoding).encode("utf-8")
msg0186 = _("Closed replace bar")#.decode(encoding).encode("utf-8")

# From filechooser.py
msg0187 = _("Closed dialog window")#.decode(encoding).encode("utf-8")
msg0188 = _("Select file for loading")#.decode(encoding).encode("utf-8")

# From error.py
msg0189 = _("Cannot open %s")#.decode(encoding).encode("utf-8")
msg0190 = _("Closed error dialog")#.decode(encoding).encode("utf-8")

# From fileloader.py
msg0191 = _("The MIME type of the file you are trying to open could not be \
determined. Make sure the file is a text file.\n\n<b>MIME type</b>: %s")#.decode(encoding).encode("utf-8")
msg0192 = _("The MIME type of the file you are trying to open is not for a \
text file.\n\n<b>MIME type</b>: %s")#.decode(encoding).encode("utf-8")

# From savechooser.py
msg0193 = _("Change name of file and save")#.decode(encoding).encode("utf-8")

# From printing.py
msg0194 = _("Print file")#.decode(encoding).encode("utf-8")
msg0195 = _("Printing \"%s\"")#.decode(encoding).encode("utf-8")

# From preferences.py
msg0196 = _("Change editor settings")#.decode(encoding).encode("utf-8")
msg0197 = _("Changed font to \"%s\"")#.decode(encoding).encode("utf-8")
msg0198 = _("Changed tab width to %d")#.decode(encoding).encode("utf-8")
msg0199 = _("Enabled text wrapping")#.decode(encoding).encode("utf-8")
msg0200 = _("Disabled text wrapping")#.decode(encoding).encode("utf-8")
msg0201 = _("Show right margin")#.decode(encoding).encode("utf-8")
msg0202 = _("Hide right margin")#.decode(encoding).encode("utf-8")
msg0203 = _("Positioned margin line at column %d")#.decode(encoding).encode("utf-8")

# From about.py
msg0204 = _("Information about the text editor")#.decode(encoding).encode("utf-8")

# From select.py
msg0205 = _("No brackets found for selection")#.decode(encoding).encode("utf-8")
msg0206 = _("Selected characters inside bracket")#.decode(encoding).encode("utf-8")

# From bracket.py
msg0207 = _("Enclosed selected text")#.decode(encoding).encode("utf-8")

# From encoding.py
msg0208 = _("English")#.decode(encoding).encode("utf-8")
msg0209 = _("Traditional Chinese")#.decode(encoding).encode("utf-8")
msg0210 = _("Traditional Chinese")#.decode(encoding).encode("utf-8")
msg0211 = _("English")#.decode(encoding).encode("utf-8")
msg0212 = _("Hebrew")#.decode(encoding).encode("utf-8")
msg0213 = _("English")#.decode(encoding).encode("utf-8")
msg0214 = _("Western Europe")#.decode(encoding).encode("utf-8")
msg0215 = _("Greek")#.decode(encoding).encode("utf-8")
msg0216 = _("Baltic languages")#.decode(encoding).encode("utf-8")
msg0217 = _("Western Europe")#.decode(encoding).encode("utf-8")
msg0218 = _("Central and Eastern Europe")#.decode(encoding).encode("utf-8")
msg0219 = _("Bulgarian, Macedonian, Russian, Serbian")#.decode(encoding).encode("utf-8")
msg0220 = _("Hebrew")#.decode(encoding).encode("utf-8")
msg0221 = _("Turkish")#.decode(encoding).encode("utf-8")
msg0222 = _("Portuguese")#.decode(encoding).encode("utf-8")
msg0223 = _("Icelandic")#.decode(encoding).encode("utf-8")
msg0224 = _("Hebrew")#.decode(encoding).encode("utf-8")
msg0225 = _("Canadian")#.decode(encoding).encode("utf-8")
msg0226 = _("Arabic")#.decode(encoding).encode("utf-8")
msg0227 = _("Danish, Norwegian")#.decode(encoding).encode("utf-8")
msg0228 = _("Russian")#.decode(encoding).encode("utf-8")
msg0229 = _("Greek")#.decode(encoding).encode("utf-8")
msg0230 = _("Thai")#.decode(encoding).encode("utf-8")
msg0231 = _("Greek")#.decode(encoding).encode("utf-8")
msg0232 = _("Japanese")#.decode(encoding).encode("utf-8")
msg0233 = _("Korean")#.decode(encoding).encode("utf-8")
msg0234 = _("Traditional Chinese")#.decode(encoding).encode("utf-8")
msg0235 = _("Urdu")#.decode(encoding).encode("utf-8")
msg0236 = _("Turkish")#.decode(encoding).encode("utf-8")
msg0237 = _("Western Europe")#.decode(encoding).encode("utf-8")
msg0238 = _("Central and Eastern Europe")#.decode(encoding).encode("utf-8")
msg0239 = _("Bulgarian, Macedonian, Russian, Serbian")#.decode(encoding).encode("utf-8")
msg0240 = _("Western Europe")#.decode(encoding).encode("utf-8")
msg0241 = _("Greek")#.decode(encoding).encode("utf-8")
msg0242 = _("Turkish")#.decode(encoding).encode("utf-8")
msg0243 = _("Hebrew")#.decode(encoding).encode("utf-8")
msg0244 = _("Arabic")#.decode(encoding).encode("utf-8")
msg0245 = _("Baltic languages")#.decode(encoding).encode("utf-8")
msg0246 = _("Vietnamese")#.decode(encoding).encode("utf-8")
msg0247 = _("Japanese")#.decode(encoding).encode("utf-8")
msg0248 = _("Japanese")#.decode(encoding).encode("utf-8")
msg0249 = _("Japanese")#.decode(encoding).encode("utf-8")
msg0250 = _("Korean")#.decode(encoding).encode("utf-8")
msg0251 = _("Simplified Chinese")#.decode(encoding).encode("utf-8")
msg0252 = _("Unified Chinese")#.decode(encoding).encode("utf-8")
msg0253 = _("Unified Chinese")#.decode(encoding).encode("utf-8")
msg0254 = _("Simplified Chinese")#.decode(encoding).encode("utf-8")
msg0255 = _("Japanese")#.decode(encoding).encode("utf-8")
msg0256 = _("Japanese")#.decode(encoding).encode("utf-8")
msg0257 = _("Japanese, Korean, Simplified Chinese")#.decode(encoding).encode("utf-8")
msg0258 = _("Japanese")#.decode(encoding).encode("utf-8")
msg0259 = _("Japanese")#.decode(encoding).encode("utf-8")
msg0260 = _("Japanese")#.decode(encoding).encode("utf-8")
msg0261 = _("Korean")#.decode(encoding).encode("utf-8")
msg0262 = _("West Europe")#.decode(encoding).encode("utf-8")
msg0263 = _("Central and Eastern Europe")#.decode(encoding).encode("utf-8")
msg0264 = _("Esperanto, Maltese")#.decode(encoding).encode("utf-8")
msg0265 = _("Baltic languagues")#.decode(encoding).encode("utf-8")
msg0266 = _("Bulgarian, Macedonian, Russian, Serbian")#.decode(encoding).encode("utf-8")
msg0267 = _("Arabic")#.decode(encoding).encode("utf-8")
msg0268 = _("Greek")#.decode(encoding).encode("utf-8")
msg0269 = _("Hebrew")#.decode(encoding).encode("utf-8")
msg0270 = _("Turkish")#.decode(encoding).encode("utf-8")
msg0271 = _("Nordic languages")#.decode(encoding).encode("utf-8")
msg0272 = _("Baltic languages")#.decode(encoding).encode("utf-8")
msg0273 = _("Celtic languages")#.decode(encoding).encode("utf-8")
msg0274 = _("Western Europe")#.decode(encoding).encode("utf-8")
msg0275 = _("Korean")#.decode(encoding).encode("utf-8")
msg0276 = _("Russian")#.decode(encoding).encode("utf-8")
msg0277 = _("Ukrainian")#.decode(encoding).encode("utf-8")
msg0278 = _("Bulgarian, Macedonian, Russian, Serbian")#.decode(encoding).encode("utf-8")
msg0279 = _("Greek")#.decode(encoding).encode("utf-8")
msg0280 = _("Icelandic")#.decode(encoding).encode("utf-8")
msg0281 = _("Central and Eastern Europe")#.decode(encoding).encode("utf-8")
msg0282 = _("Western Europe")#.decode(encoding).encode("utf-8")
msg0283 = _("Turkish")#.decode(encoding).encode("utf-8")
msg0284 = _("Kazakh")#.decode(encoding).encode("utf-8")
msg0285 = _("Japanese")#.decode(encoding).encode("utf-8")
msg0286 = _("Japanese")#.decode(encoding).encode("utf-8")
msg0287 = _("Japanese")#.decode(encoding).encode("utf-8")
msg0288 = _("All languages")#.decode(encoding).encode("utf-8")
msg0289 = _("All Languages (BMP only)")#.decode(encoding).encode("utf-8")
msg0290 = _("All Languages (BMP only)")#.decode(encoding).encode("utf-8")
msg0291 = _("All Languages")#.decode(encoding).encode("utf-8")
msg0292 = _("None")#.decode(encoding).encode("utf-8")


# From indent.py
msg0293 = _("Replaced tabs with spaces on selected lines")#.decode(encoding).encode("utf-8")

# From scribes.desktop
msg0294 = _("Scribes Text Editor")#.decode(encoding).encode("utf-8")
msg0295 = _("Edit text files")#.decode(encoding).encode("utf-8")

# From syntaxcoloreditor.py
msg0296 = _("Syntax Color Editor")#.decode(encoding).encode("utf-8")
msg0297 = _("_Use default theme")#.decode(encoding).encode("utf-8")
msg0298 = _("_Normal text color: ")#.decode(encoding).encode("utf-8")
msg0299 = _("_Background color: ")#.decode(encoding).encode("utf-8")
msg0300 = _("Language Elements")#.decode(encoding).encode("utf-8")
msg0301 = _("Co_lor: ")#.decode(encoding).encode("utf-8")
msg0302 = _("B_old")#.decode(encoding).encode("utf-8")
msg0303 = _("I_talic")#.decode(encoding).encode("utf-8")
msg0304 = _("_Reset to Default")#.decode(encoding).encode("utf-8")

# From templateseditor.py
msg0305 = _("Template Editor")#.decode(encoding).encode("utf-8")
msg0306 = _("_Language")#.decode(encoding).encode("utf-8")
msg0307 = _("_Name")#.decode(encoding).encode("utf-8")
msg0308 = _("Description")#.decode(encoding).encode("utf-8")

# From templateadd.py
msg0309 = _("_Name:")#.decode(encoding).encode("utf-8")
msg0310 = _("_Description:")#.decode(encoding).encode("utf-8")
msg0311 = _("_Template:")#.decode(encoding).encode("utf-8")
msg0312 = _("Add New Template")#.decode(encoding).encode("utf-8")

# From templateedit.py
msg0313 = _("Edit Template")#.decode(encoding).encode("utf-8")

# From tooltips.py
msg0314 = _("Select to use themes' foreground and background colors")#.decode(encoding).encode("utf-8")
msg0315 = _("Click to choose a new color for the editor's text")#.decode(encoding).encode("utf-8")
msg0316 = _("Click to choose a new color for the editor's background")#.decode(encoding).encode("utf-8")
msg0317 = _("Click to choose a new color for the language syntax element")#.decode(encoding).encode("utf-8")
msg0318 = _("Select to make the language syntax element bold")#.decode(encoding).encode("utf-8")
msg0319 = _("Select to make the language syntax element italic")#.decode(encoding).encode("utf-8")
msg0320 = _("Select to reset the language syntax element to its default \
settings")#.decode(encoding).encode("utf-8")

# From syntaxcoloreditor.py
msg0321 = _("Change editor colors")#.decode(encoding).encode("utf-8")

# From readonly.py
msg0322 = _("Toggled readonly mode on")#.decode(encoding).encode("utf-8")
msg0323 = _("File has not been saved to disk")#.decode(encoding).encode("utf-8")
msg0324 = _("Toggled readonly mode off")#.decode(encoding).encode("utf-8")
msg0325 = _("No permission to modify file")#.decode(encoding).encode("utf-8")

# From tooltips.py
msg0326 = _("Menu for advanced configuration")#.decode(encoding).encode("utf-8")
msg0327 = _("Configure the editor's foreground, background or syntax colors")#.decode(encoding).encode("utf-8")
msg0328 = _("Create, modify or manage templates")#.decode(encoding).encode("utf-8")

# From cursor.py
msg0329 = _("Ln %d col %d")#.decode(encoding).encode("utf-8")

# From passworddialog.py
msg0330 = _("Authentication Required")
msg0331 = _("You must log in to access %s")
msg0332 = _("_Password:")
msg0333 = _("_Remember password for this session")
msg0334 = _("Save password in _keyring")

# From fileloader.py
msg0335 = _("Loading \"%s\"...")

# From bookmarkbrowser.py
msg0336 = _("Bookmark Browser")
msg0337 = _("Line")
msg0338 = _("Bookmarked Text")
msg0339 = _("No bookmarks found")

# From bookmark.py
msg0340 = _("Moved to most recently bookmarked line")
msg0341 = _("Already on most recently bookmarked line")
msg0342 = _("No bookmarks found")


# From dialogfilter.py
msg0343 = _("Ruby Documents")
msg0344 = _("Perl Documents")
msg0345 = _("C Documents")
msg0346 = _("C++ Documents")
msg0347 = _("C# Documents")
msg0348 = _("Java Documents")
msg0349 = _("PHP Documents")
msg0350 = _("HTML Documents")
msg0351 = _("XML Documents")
msg0352 = _("Haskell Documents")
msg0353 = _("Scheme Documents")

# From textview.py
msg0354 = _("INS")
msg0355 = _("OVR")

# From remotedialog.py
msg0356 = _("Enter the location (URI) of the file you _would like to open:")
msg0357 = _("Type URI for loading")

# From loader.py
msg0358 = _("Open Error: An error occurred while opening the file. Try opening \
the file again or file a bug report.")
msg0359 = _("Info Error: Information on %s cannot be retrieved.")
msg0360 = _("Info Error: Access has been denied to the requested file.")
msg0361 = _("Permission Error: Access has been denied to the requested file.")
msg0362 =_("Cannot open file")

# From save.py
msg0363 = _("You do not have permission to save the file. Try saving the file \
to your desktop, or to a folder you own. Automatic saving has been disabled \
until the file is saved correctly without errors.")
msg0364 = _("A saving operation failed. Could not create swap area. Make sure \
you have permission to save to your home folder. Also check to see that you \
have not run out of disk space. Automatic saving will be disabled until the \
document is properly saved.")
msg0365 = _("An error occured while creating the file. Automatic saving has \
been disabled until the file is saved correctly without errors.")
msg0366 = _("A saving error occured. The document could not be transfered from \
its temporary location. Automatic saving has been disabled until the file is \
saved correctly without errors.")
msg0367 = _("You do not have permission to save the file. Automatic saving \
will be disabled until the file is properly saved.")
msg0368 = _("A decoding error occured while saving the file. Automatic saving \
will be disabled until the file is properly saved.")
msg0369 = _("An encoding error occurred while saving the file. Automatic \
saving will be disabled until the file is properly saved.")

# From findprevious.py
msg0370 = _("Match %d of %d")

# From regexbar.py
msg0371 = _("Search for text using regular expression")
msg0372 = _("Close regular expression bar")

# From incsearchbar.py
msg0373 = _("Incrementally search for text")
msg0374 = _("Close incremental search bar")

# From findbar.py
msg0375 = _("Searching please wait...")

# From findstopbutton.py
msg0376 = _("Stopped operation")

# From findnextbutton.py
msg0377 = _("No next match found")

# From replacebar.py
msg0378 = _("Replacing please wait...")

# From replacestopbutton.py
msg0379 = _("Stopped replacing")

# From popupindent.py
msg0380 = _("I_ndentation")

# From actions.py
msg0381 = _("Replacing spaces please wait...")
msg0382 = _("Replaced spaces with tabs")
msg0383 = _("No spaces found to replace")
msg0384 = _("Replacing tabs please wait...")
msg0385 = _("Replaced tabs with spaces")
msg0386 = _("No tabs found to replace")
msg0387 = _("Removed spaces at end of lines")

# From popupspaces.py
msg0388 = _("S_paces")
msg0389 = _("_Tabs to Spaces")
msg0390 = _("_Spaces to Tabs")
msg0391 = _("_Remove Trailing Spaces")

# From popupselection.py
msg0392 = _("S_election")
msg0393 = _("Select _Word")
msg0394 = _("Select _Line")

# From popuplines.py
msg0395 = _("_Lines")
msg0396 = _("_Delete Line")
msg0397 = _("_Join Line")
msg0398 = _("Free Line _Above")
msg0399 = _("Free Line _Below")
msg0400 = _("Delete Cursor to Line _End")
msg0401 = _("Delete _Cursor to Line Begin")

# From popupselection.py
msg0402 = _("Select _Sentence")
msg0403 = _("Select _Paragraph")

# From popupbookmarks.py
msg0404 = _("_Bookmark")
msg0405 = _("Bookmark _Line")
msg0406 = _("_Remove Bookmark")
msg0407 = _("Remove _All Bookmarks")
msg0408 = _("Move to _Next Bookmark")
msg0409 = _("Move to _Previous Bookmark")
msg0410 = _("Move to _First Bookmark")
msg0411 = _("Move to Last _Bookmark")
msg0412 = _("_Show Bookmark Browser")

# From bookmarktriggers.py
msg0413 = _("Moved to first bookmark")
msg0414 = _("Moved to last bookmark")
msg0415 = _("Already on first bookmark")
msg0416 = _("Already on last bookmark")

# From bookmarkbrowser.py
msg0417 = _("Move to bookmarked line")

# From replaceincrementalbutton.py
msg0418 = _("Incre_mental")

# templateeditorexportbutton.py
msg0419 = _("E_xport")

# templateeditorimportbutton.py
msg0420 = _("I_mport")

# templateadddialog.py
msg0421 = _("Error: Name field must contain a string.")
msg0422 = _("Error: '%s' already in use. Please choose another string.")
msg0423 = _("Error: Name field cannot have any spaces.")
msg0424 = _("Error: Template editor can only have one '${cursor}' placeholder.")

# importdialog.py
msg0425 = _("Error: Invalid template file.")
msg0426 = _("Import Template")

# exportdialog.py
msg0427 = _("Export Template")

# bookmarktrigger.py
msg0428 = _("No bookmarks found")

# actions.py
msg0429 = _("Could not open help browser")

# preftabcheckbutton.py
msg0430 = _("_Use spaces instead of tabs")
msg0431 = _("Use tabs for indentation")
msg0432 = _("Use spaces for indentation")

msg0433 = _("Enabled spellchecking")
msg0434 = _("Disabled spellchecking")
msg0435 = _("Use spaces instead of tabs for indentation")

msg0436 = _("Using theme colors")
msg0437 = _("Using custom colors")

msg0438 = _("Select foreground color")
msg0439 = _("Select background color")
msg0440 = _("Select foreground syntax color")
msg0441 = _("Select background syntax color")
msg0442 = _("_Foreground:")
msg0443 = _("Back_ground:")
msg0444 = _("B_old")
msg0445 = _("I_talic")
msg0446 = _("_Underline")
msg0447 = _("Select to underline language syntax element")

msg0448 = _("Select document to focus")
msg0449 = _("Open Documents")
msg0450 = _("File _Type")
msg0451 = _("File _Name")
msg0452 = _("Full _Path Name")
msg0453 = _("No documents open")
msg0454 = _("Current document is focused")

msg0455 = _("_Case")
msg0456 = _("_Uppercase")
msg0457 = _("_Lowercase")
msg0458 = _("_Titlecase")
msg0459 = _("_Swapcase")

msg0460 = _("Open recently used files")
msg0461 = _("No previous match found")
msg0462 = _("Replace found match")
msg0463 = _("Replaced all found matches")

msg0464 = _("Inserted template")
msg0465 = _("Selected next placeholder")
msg0466 = _("Selected previous placeholder")
msg0467 = _("Template mode is active")
