# -*- coding: utf-8 -*-
# Copyright (C) 2005 Lateef Alabi-Oki
#
# This file is part of Scribes.
#
# Scribes is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Scribes is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Scribes; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

"""
This module contains the function to the main entry point of the
program.

@author: Lateef Alabi-Oki
@organization: The Scribes Project
@copyright: Copyright © 2005 Lateef Alabi-Oki
@license: GNU GPLv2 or Later
@contact: mystilleef@gmail.com
"""

def main(uri_list=None):
	"""
	Main entry point to the program.

	This function connects to the GTK+ main loop. It also launches
	an instance of the text editor. If files are passed as arguments,
	each file is launched in a new instance of the text editor.

	@param uri_list: A list of URIs
	@type uri_list:	A List object.
	"""
	from gtk import main
	from gtk.gdk import threads_enter, threads_leave
	from gobject import timeout_add, PRIORITY_HIGH, threads_init
	if uri_list:
		# Launch each file in a new instance of the text editor.
		uri_list = " ".join(uri_list).split(" ")
		threads_enter()
		timeout_add(7, launch_new_editor, uri_list, priority=PRIORITY_HIGH)
		threads_leave()
		fork_scribes()
	else:
		# Launch an instance of the text editor without files.
		threads_enter()
		timeout_add(7, launch_new_editor, priority=PRIORITY_HIGH)
		threads_leave()
		fork_scribes()
	# Connect to the GTK+ main loop.
	threads_init()
	threads_enter()
	main()
	threads_leave()
	return

def launch_new_editor(uri_list=None):
	"""
	Create one or more instances of the text editor.

	If files are passed as arguments, each file is loaded in a new
	instance of the text editor.

	@param uri_list: A list of URIs.
	@type uri_list: A List object.

	@return: False to prevent repeated calls of this function.
	@rtype: A Boolean object.
	"""
	from editor import Editor
	if uri_list:
		Editor(uri_list)
	else:
		Editor()
	return False

def fork_scribes():
	"""
	Fork the text editor's process to free the terminal.
	"""
	from os import fork
	pid = fork()
	if pid != 0:
		from sys import exit
		exit(0)
	return
