# -*- coding: utf-8 -*-
# Copyright © 2005 Lateef Alabi-Oki
#
# This file is part of Scribes.
#
# Scribes is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Scribes is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Scribes; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

"""
This module exposes a class that creates the main container for the text editor.

@author: Lateef Alabi-Oki
@organization: The Scribes Project
@copyright: Copyright © 2005 Lateef Alabi-Oki
@license: GNU GPLv2 or Later
@contact: mystilleef@gmail.com
"""

from gtk import VBox

class ScribesMainContainer(VBox):
	"""
	This class creates the main container object for the text editor. The main
	container is the topmost container object. The main container is embedded
	within the text editor's window.
	"""

	def __init__(self, editor):
		"""
		Initialize the text editor's topmost container object and set its
		default properties and state.

		@param self: Reference to the ScribesMainContainer instance.
		@type self: A ScribesMainContainer object.

		@param editor: Reference to the text editor.
		@type editor: An Editor object.
		"""
		from utils import response
		response()
		VBox.__init__(self)
		self.__init_attributes(editor)
		self.__set_properties()
		self.resize_children()
		self.editor.connect("show-bar", self.__maincontainer_show_bar_cb)
		self.editor.connect("hide-bar", self.__maincontainer_hide_bar_cb) 

	def __init_attributes(self, editor):
		"""
		Initialize the main container's attributes.

		@param self: Reference to the ScribesMainContainer instance.
		@type self: A ScribesMainContainer object.

		@param editor: Reference to the text editor.
		@type editor: An Editor object.
		"""
		self.editor = editor
		self.bar_is_visible = False
		return

	def __set_properties(self):
		"""
		Set the main container's properties.

		@param self: Reference to the ScribesMainContainer instance.
		@type self: A ScribesMainContainer object.
		"""
		from gtk import RESIZE_PARENT
		self.set_property("resize-mode", RESIZE_PARENT)
		self.set_property("parent", self.editor.window)
		self.set_property("name", "scribesmaincontainer")
		return

	def __maincontainer_show_bar_cb(self, editor, bar):
		"""
		Handles callback when the "show-bar" signal is emitted.

		@param self: Reference to the ScribesMainContainer instance.
		@type self: A ScribesMainContainer object.

		@param editor: Reference to the text editor.
		@type editor: An Editor object.

		@param bar: The text editor's bar.
		@type bar: A ScribesBar object.
		"""
		if self.bar_is_visible:
			return
		self.pack_start(bar, False, False, 0)
		self.reorder_child(bar, 2)
		bar.show_all()
		self.bar_is_visible = True
		return

	def __maincontainer_hide_bar_cb(self, editor, bar):
		"""
		Handles callback when the "show-bar" signal is emitted.

		@param self: Reference to the ScribesMainContainer instance.
		@type self: A ScribesMainContainer object.

		@param editor: Reference to the text editor.
		@type editor: An Editor object.

		@param bar: The text editor's bar.
		@type bar: A ScribesBar object.
		"""
		bar.hide_all()
		self.bar_is_visible = False
		self.remove(bar)
		return
