# -*- coding: utf-8 -*-
# Copyright © 2005 Lateef Alabi-Oki
#
# This file is part of Scribes.
#
# Scribes is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Scribes is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Scribes; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

#from dialog import ScribesDialog
from gtk import FileChooserDialog

class ScribesOpenDialog(FileChooserDialog):
	"""
	This class instantiates a dialog that allows clients to select and load
	files into the text editor. It inherites from ScribesDialog and the
	gtk.FileChooserDialog classes. See dialog.py and the GTK+ manual
	respectively for the properties of each class.
	"""

	def __init__(self, editor):
		"""
		Initialize the text editor's open dialog.

		@param self: Reference to the ScribesOpenDialog instance.
		@type self: A ScribesOpenDialog object.

		@param window: A possible parent window.
		@type window: A gtk.Window object.
		"""
		FileChooserDialog.__init__(self)
		#ScribesDialog.__init__(self, editor)
		self.__init_attributes(editor)
		self.__set_dialog_properties()
		self.editor.connect("show-dialog", self.__dialog_show_dialog_cb)
		self.editor.connect("loaded-document", self.__dialog_reset_flags_cb)
		self.editor.connect("renamed-document", self.__dialog_reset_flags_cb)

	def __init_attributes(self, editor):
		"""
		Initialize the dialog attributes.

		@param self: Reference to the ScribesOpenDialog instance.
		@type self: A ScribesOpenDialog object.

		@param window: A possible parent window.
		@type window: A gtk.Window object.
		"""
		self.editor = editor
		self.is_first_time_displayed = True
		self.parent_window = editor.window
		self.uri = editor.uri
		self.encoding  = None
		from encodingbox import ScribesEncodingComboBox
		self.combobox = ScribesEncodingComboBox(editor)
		from utils import create_encoding_box
		self.encoding_box  = create_encoding_box(self.combobox)
		self.__shortcut_folder_is_set = False
		return

	def __set_dialog_properties(self):
		"""
		Set the dialog properties.

		@param self: Reference to the ScribesOpenDialog instance.
		@type self: A ScribesOpenDialog object.
		"""
		from utils import calculate_resolution_independence
		width, height = calculate_resolution_independence(self.parent_window,
														1.6, 1.929648241)
		self.set_default_size(width, height)
		from internationalization import msg0026
		self.set_property("title", msg0026)
		self.set_property("role", "scribes_open_dialog")
		self.set_property("icon-name", "stock_open")
		self.set_property("local-only", False)
		self.set_property("select-multiple", True)
		self.set_property("name", "scribesopendialog")
		from gtk import STOCK_OPEN, STOCK_CANCEL, RESPONSE_OK, RESPONSE_CANCEL
		self.add_button(STOCK_CANCEL, RESPONSE_CANCEL)
		self.add_button(STOCK_OPEN, RESPONSE_OK)
		self.set_extra_widget(self.encoding_box)
		self.set_default_response(RESPONSE_OK)
		self.set_transient_for(self.editor.window)
		from dialogfilter import create_filter_list
		for filter in create_filter_list():
			self.add_filter(filter)
		return

	def show_dialog(self):
		"""
		Show the text editor's open dialog.

		@param self: Reference to the ScribesOpenDialog instance.
		@type self: A ScribesOpenDialog object.
		"""
		# Get the uri of the file loaded in the buffer again because the initial
		# value of uri, None, may have changed.
		self.uri = self.editor.uri
		self.editor.emit("show-dialog", self)
		from internationalization import msg0188
		status_id = self.editor.feedback.set_modal_message(msg0188, "open")
		self.show_all()
		response = self.run()
		from gobject import timeout_add
		timeout_add(7, self.editor.feedback.unset_modal_message, status_id)
		from gtk import RESPONSE_OK
		self.editor.emit("hide-dialog", self)
		self.hide()
		if response == RESPONSE_OK:
			# Load selected uri(s) into the text editor's buffer.
			uri_list = self.get_uris()
			#if self.editor.uri:
			#	if str(self.editor.uri) in [uri_list]:
			#		uri_list.remove(str(self.editor.uri))
			#		if not uri_list:
			#			self.editor.window.hide()
			#			self.editor.window.present()
			#			return
			#from thread import start_new_thread
			#from utils import response
			#from gtk import threads_enter, threads_leave
			#response()
			#threads_enter()
			#start_new_thread(LoadURI, (self.editor, uri_list))
			#start_new_thread(self.editor.fileloader.load_uris, (uri_list,))
			#threads_leave()
			#response()
			self.editor.fileloader.load_uris(uri_list)
		return

	def __dialog_show_dialog_cb(self, editor, dialog):
		if not dialog.get_property("name") in ["scribesopendialog"]:
			return
		if self.uri:
			try:
				if self.__shortcut_folder_is_set is False:
					from gobject import GError
					self.add_shortcut_folder_uri(str(self.uri.parent))
					self.__shortcut_folder_is_set = True
			except GError:
				self.__shortcut_folder_is_set = True
			if self.is_first_time_displayed:
				self.select_uri(str(self.uri))
		self.is_first_time_displayed = False
		return

	def __dialog_reset_flags_cb(self, editor):
		self.is_first_time_displayed = True
		self.__shortcut_folder_is_set = False
		return
