# -*- coding: utf-8 -*-
# Copyright © 2005 Lateef Alabi-Oki
#
# This file is part of Scribes.
#
# Scribes is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Scribes is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Scribes; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

from gtk import ImageMenuItem

class ScribesBookmarksPopupMenuItem(ImageMenuItem):
	"""
	This class creates the bookmarks popup menu for the text editor.
	"""

	def __init__(self, scribesview):
		"""
		Initialize the popup menu.

		@param self: Reference to the ScribesBookmarksPopupMenuItem instance.
		@type self: A ScribesBookmarksPopupMenuItem object.

		@param scribesview: The text editor's text view.
		@type scribesview: A ScribesTextView object.
		"""
		from internationalization import msg0404
		ImageMenuItem.__init__(self, msg0404)
		self.__init_attributes(scribesview)
		self.__create_widgets()
		self.__set_properties()
		self.bookmark_line_menuitem.connect("activate", self.__popup_activate_cb)
		self.remove_bookmark_menuitem.connect("map-event", self.__popup_map_event_cb)
		self.remove_bookmark_menuitem.connect("activate", self.__popup_activate_cb)
		self.remove_all_bookmarks_menuitem.connect("map-event", self.__popup_map_event2_cb)
		self.remove_all_bookmarks_menuitem.connect("activate", self.__popup_activate_cb)
		self.next_bookmark_menuitem.connect("activate", self.__popup_activate_cb)
		self.next_bookmark_menuitem.connect("map-event", self.__popup_map_event2_cb)
		self.previous_bookmark_menuitem.connect("activate", self.__popup_activate_cb)
		self.previous_bookmark_menuitem.connect("map-event", self.__popup_map_event2_cb)
		self.first_bookmark_menuitem.connect("activate", self.__popup_activate_cb)
		self.first_bookmark_menuitem.connect("map-event", self.__popup_map_event2_cb)
		self.last_bookmark_menuitem.connect("activate", self.__popup_activate_cb)
		self.last_bookmark_menuitem.connect("map-event", self.__popup_map_event2_cb)
		self.show_browser_menuitem.connect("activate", self.__popup_activate_cb)
		self.show_browser_menuitem.connect("map-event", self.__popup_map_event_cb)

	def __init_attributes(self, scribesview):
		"""
		Initialize the popup's attributes.

		@param self: Reference to the ScribesBookmarksPopupMenuItem instance.
		@type self: A ScribesBookmarksPopupMenuItem object.

		@param scribesview: The text editor's text view.
		@type scribesview: A ScribesTextView object.
		"""
		self.scribesview = scribesview
		self.editor = scribesview.editor
		self.menu = None
		self.image = None
		self.bookmark_line_menuitem = None
		self.remove_bookmark_menuitem = None
		self.remove_all_bookmarks_menuitem = None
		self.next_bookmark_menuitem = None
		self.previous_bookmark_menuitem = None
		self.first_bookmark_menuitem = None
		self.last_bookmark_menuitem = None
		self.show_browser_menuitem = None
		return

	def __create_widgets(self):
		"""
		Create menu items for the bookmarks menu.

		@param self: Reference to the ScribesBookmarksPopupMenuItem instance.
		@type self: A ScribesBookmarksPopupMenuItem object.
		"""
		from gtk import Menu
		from utils import create_image
		from info import scribes_data_folder
		image = scribes_data_folder + "/bookmarks.png"
		self.image = create_image(image)
		self.menu = Menu()
		from utils import create_menuitem
		from internationalization import msg0405, msg0406
		from internationalization import msg0407, msg0408, msg0409
		from internationalization import msg0410, msg0411, msg0412
		self.bookmark_line_menuitem = create_menuitem(msg0405)
		self.remove_bookmark_menuitem = create_menuitem(msg0406)
		self.remove_all_bookmarks_menuitem = create_menuitem(msg0407)
		self.next_bookmark_menuitem = create_menuitem(msg0408)
		self.previous_bookmark_menuitem = create_menuitem(msg0409)
		self.first_bookmark_menuitem = create_menuitem(msg0410)
		self.last_bookmark_menuitem = create_menuitem(msg0411)
		self.show_browser_menuitem = create_menuitem(msg0412)
		return

	def __set_properties(self):
		"""
		Set the menu item's properties.

		@param self: Reference to the ScribesBookmarksPopupMenuItem instance.
		@type self: A ScribesBookmarksPopupMenuItem object.
		"""
		self.set_image(self.image)
		self.set_submenu(self.menu)
		self.menu.append(self.bookmark_line_menuitem)
		self.menu.append(self.remove_bookmark_menuitem)
		self.menu.append(self.remove_all_bookmarks_menuitem)
		self.menu.append(self.next_bookmark_menuitem)
		self.menu.append(self.previous_bookmark_menuitem)
		self.menu.append(self.first_bookmark_menuitem)
		self.menu.append(self.last_bookmark_menuitem)
		self.menu.append(self.show_browser_menuitem)
		if self.editor.is_readonly:
			self.set_property("sensitive", False)
		return

	def __popup_activate_cb(self, menuitem):
		"""
		Handles callback when the "activate" signal is emitted.

		@param self: Reference to the ScribesBookmarksPopupMenuItem instance.
		@type self: A ScribesBookmarksPopupMenuItem object.

		@param menuitem: The popup menu's menuitem.
		@type menuitem: A gtk.MenuItem object.

		@return: True to propagate signals to parent widgets.
		@type: A Boolean Object.
		"""
		if menuitem == self.show_browser_menuitem:
			self.editor.triggermanager.trigger("show_bookmark_browser")
		elif menuitem == self.bookmark_line_menuitem:
			self.editor.triggermanager.trigger("bookmark_line")
		elif menuitem == self.remove_bookmark_menuitem:
			self.editor.triggermanager.trigger("remove_bookmark")
		elif menuitem == self.remove_all_bookmarks_menuitem:
			self.editor.triggermanager.trigger("remove_all_bookmarks")
		elif menuitem == self.next_bookmark_menuitem:
			self.editor.triggermanager.trigger("next_bookmark")
		elif menuitem == self.previous_bookmark_menuitem:
			self.editor.triggermanager.trigger("previous_bookmark")
		elif menuitem == self.first_bookmark_menuitem:
			self.editor.triggermanager.trigger("first_bookmark")
		elif menuitem == self.last_bookmark_menuitem:
			self.editor.triggermanager.trigger("last_bookmark")
		return True

	def __popup_map_event_cb(self, menuitem, event):
		"""
		Handles callback when the "map-event" signal is emitted.

		@param self: Reference to the ScribesBookmarksPopupMenuItem instance.
		@type self: A ScribesBookmarksPopupMenuItem object.

		@param menuitem: The popup menu's menuitem.
		@type menuitem: A gtk.MenuItem object.

		@param event: An event that occurs when popup menu is displayed.
		@type event: A gtk.Event object.
		"""
		menuitem.set_property("sensitive", False)
		try:
			lines = self.editor.bookmark_manager.get_bookmarked_lines()
			if lines:
				menuitem.set_property("sensitive", True)
		except:
			pass
		return True

	def __popup_map_event2_cb(self, menuitem, event):
		"""
		Handles callback when the "map-event" signal is emitted.

		@param self: Reference to the ScribesBookmarksPopupMenuItem instance.
		@type self: A ScribesBookmarksPopupMenuItem object.

		@param menuitem: The popup menu's menuitem.
		@type menuitem: A gtk.MenuItem object.

		@param event: An event that occurs when popup menu is displayed.
		@type event: A gtk.Event object.
		"""
		menuitem.set_property("sensitive", False)
		try:
			lines = self.editor.bookmark_manager.get_bookmarked_lines()
			if len(lines) > 1:
				menuitem.set_property("sensitive", True)
		except:
			pass
		return True
