# -*- coding: utf-8 -*-
# Copyright © 2005 Lateef Alabi-Oki
#
# This file is part of Scribes.
#
# Scribes is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Scribes is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Scribes; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

"""
This module documents a class that creates a trigger to show the text
editor's preference dialog.

@author: Lateef Alabi-Oki
@organization: The Scribes Project
@copyright: Copyright © 2005 Lateef Alabi-Oki
@license: GNU GPLv2 or Later
@contact: mystilleef@gmail.com
"""

class PreferencesTrigger(object):
	"""
	This class creates an object, a trigger, that allows users to show
	a preference dialog.
	"""

	def __init__(self, editor):
		"""
		Initialize the trigger.

		@param self: Reference to the PreferencesTrigger instance.
		@type self: A PreferencesTrigger object.

		@param editor: Reference to the text editor.
		@type editor: An Editor object.
		"""
		self.__init_attributes(editor)
		self.__create_trigger()
		self.__trigger.connect("activate", self.__show_preference_dialog_cb)

	def __init_attributes(self, editor):
		"""
		Initialize the trigger's attributes.

		@param self: Reference to the PreferencesTrigger instance.
		@type self: A PreferencesTrigger object.

		@param editor: Reference to the text editor.
		@type editor: An Editor object.
		"""
		self.__editor = editor
		self.__preference_dialog = None
		self.__trigger = None
		return

	def __create_trigger(self):
		"""
		Create the trigger.

		@param self: Reference to the PreferencesTrigger instance.
		@type self: A PreferencesTrigger object.
		"""
		# Trigger to show the preference dialog.
		from trigger import Trigger
		self.__trigger = Trigger("show_preference_dialog")
		self.__editor.triggermanager.add_trigger(self.__trigger, "F12")
		return

	def __show_preference_dialog_cb(self, trigger):
		"""
		Handles callback when the "activate" signal is emitted.

		@param self: Reference to the PreferencesTrigger instance.
		@type self: A PreferencesTrigger object.

		@param trigger: An object to show the document browser.
		@type trigger: A Trigger object.
		"""
		try:
			self.__preference_dialog.show_dialog()
		except AttributeError:
			from preferences import PreferenceDialog
			self.__preference_dialog = PreferenceDialog(self.__editor)
			self.__preference_dialog.show_dialog()
		return
