# -*- coding: utf-8 -*-
# Copyright © 2005 Lateef Alabi-Oki
#
# This file is part of Scribes.
#
# Scribes is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Scribes is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Scribes; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

"""
This module documents a class that creates a trigger for the text
editor's save dialog.

@author: Lateef Alabi-Oki
@organization: The Scribes Project
@copyright: Copyright © 2005 Lateef Alabi-Oki
@license: GNU GPLv2 or Later
@contact: mystilleef@gmail.com
"""

class SaveDialogTrigger(object):
	"""
	This class creates an object that shows the text editor's save
	dialog.
	"""

	def __init__(self, editor):
		"""
		Initialize the trigger.

		@param self: Reference to the SaveDialogTrigger instance.
		@type self: An SaveDialogTrigger object.

		@param editor: Reference to the text editor.
		@type editor: An Editor object.
		"""
		self.__init_attributes(editor)
		self.__create_trigger()
		self.__trigger.connect("activate", self.__show_save_dialog_cb)

	def __init_attributes(self, editor):
		"""
		Initialize the trigger's attributes.

		@param self: Reference to the SaveDialogTrigger instance.
		@type self: A SaveDialogTrigger object.

		@param editor: Reference to the text editor.
		@type editor: An Editor object.
		"""
		self.__editor = editor
		self.__save_dialog = None
		self.__trigger = None
		return

	def __create_trigger(self):
		"""
		Create the trigger.

		@param self: Reference to the SaveDialogTrigger instance.
		@type self: A SaveDialogTrigger object.
		"""
		# Trigger to show the open dialog.
		from trigger import Trigger
		self.__trigger = Trigger("show_save_dialog")
		self.__editor.triggermanager.add_trigger(self.__trigger, "control - S")
		return

	def __show_save_dialog_cb(self, trigger):
		"""
		Handles callback when the "activate" signal is emitted.

		@param self: Reference to the SaveDialogTrigger instance.
		@type self: A SaveDialogTrigger object.

		@param trigger: An object to show the document browser.
		@type trigger: A Trigger object.
		"""
		try:
			self.__save_dialog.show_dialog()
		except AttributeError:
			from savedialog import ScribesSaveDialog
			self.__save_dialog = ScribesSaveDialog(self.__editor)
			self.__save_dialog.show_dialog()
		return
