# -*- coding: utf-8 -*-
# Copyright © 2005 Lateef Alabi-Oki
#
# This file is part of Scribes.
#
# Scribes is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Scribes is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Scribes; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

"""
This module exposes a class that initializes custom signals for the text editor.

@author: Lateef Alabi-Oki
@organization: The Scribes Project
@copyright: Copyright © 2005 Lateef Alabi-Oki
@license: GNU GPLv2 or Later
@contact: mystilleef@gmail.com
"""

from gobject import GObject, SIGNAL_RUN_LAST, TYPE_NONE, TYPE_OBJECT

class ScribesSignals(GObject):
	"""
	This class creates an object that initializes signals for the text editor.
	It is designed primary for inheritance by the Editor object.
	"""

	__gsignals__ = {
		"checking-document": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
		"loading-document": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
		"loaded-document": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
		"load-error": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
		"enable-readonly": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
		"disable-readonly": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
		"saving-document": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
		"saved-document": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
		"save-error": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
		"gui-created": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
		"show-dialog": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
		"hide-dialog": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
		"renamed-document": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
		"close-document": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
		"created-widgets": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
		"enable-fullscreen": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
		"disable-fullscreen": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
		"not-yet-implemented": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
		"show-bar": (SIGNAL_RUN_LAST, TYPE_NONE, (TYPE_OBJECT,)),
		"hide-bar": (SIGNAL_RUN_LAST, TYPE_NONE, (TYPE_OBJECT,)),
	}

	def __init__(self):
		"""
		Initialize signals for the text editor.

		@param self: Reference to the ScribesSignals instance.
		@type self: A ScribesSignals object.
		"""
	 	GObject.__init__(self)
		from gobject import type_register
		type_register(type(self))
