# -*- coding: utf-8 -*-
# Copyright © 2005 Lateef Alabi-Oki
#
# This file is part of Scribes.
#
# Scribes is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Scribes is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Scribes; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

"""
This module exposes a class that creates the container for the editor's
statusbar area.

@author: Lateef Alabi-Oki
@organization: The Scribes Project
@copyright: Copyright © 2005 Lateef Alabi-Oki
@license: GNU GPLv2 or Later
@contact: mystilleef@gmail.com
"""

from gtk import HBox

class ScribesStatusContainer(HBox):
	"""
	This class creates the statusbar container object for the text editor. The
	object houses the text editor's statusbar.
	"""

	def __init__(self, editor):
		"""
		Initialize the text editor's statusbar container and set its default
		state and properties.

		@param self: Reference to the ScribesStatusContainer instance.
		@type self: A ScribesStatusContainer object.

		@param editor: Reference to the text editor.
		@type editor: An Editor object.
		"""
		from utils import response
		response()
		HBox.__init__(self)
		self.__init_attributes(editor)
		self.__set_properties()
		self.resize_children()
		self.editor.connect("enable-fullscreen", self.__status_enable_fullscreen_cb)
		self.editor.connect("disable-fullscreen", self.__status_disable_fullscreen_cb)

	def __init_attributes(self, editor):
		"""
		Initialize the container's attributes.

		@param self: Reference to the ScribesStatusContainer instance.
		@type self: A ScribesStatusContainer object.

		@param editor: Reference to the text editor.
		@type editor: An Editor object.
		"""
		self.editor = editor
		return

	def __set_properties(self):
		"""
		Set the container's properties.

		@param self: Reference to the ScribesStatusContainer instance.
		@type self: A ScribesStatusContainer object.
		"""
		from gtk import RESIZE_PARENT
		self.set_property("resize-mode", RESIZE_PARENT)
		self.set_property("name", "scribesstatuscontainer")
		return

	def __status_enable_fullscreen_cb(self, editor):
		"""
		Handles callback when the "enable-fullscreen" signal is emitted.

		@param self: Reference to the ScribesStatusContainer instance.
		@type self: A ScribesStatusContainer object.

		@param editor: Reference to the text editor.
		@type editor: An Editor object.
		"""
		self.hide_all()
		return

	def __status_disable_fullscreen_cb(self, editor):
		"""
		Handles callback when the "disable-fullscreen" signal is emitted.

		@param self: Reference to the ScribesStatusContainer instance.
		@type self: A ScribesStatusContainer object.

		@param editor: Reference to the text editor.
		@type editor: An Editor object.
		"""
		self.show_all()
		return
