# -*- coding: utf-8 -*-
# Copyright © 2005 Lateef Alabi-Oki
#
# This file is part of Scribes.
#
# Scribes is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Scribes is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Scribes; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

"""
This module documents a class that creates the template editor's edit
dialog.

@author: Lateef Alabi-Oki
@organization: The Scribes Project
@copyright: Copyright © 2005 Lateef Alabi-Oki
@license: GNU GPLv2 or Later
@contact: mystilleef@gmail.com
"""

from templateadddialog import TemplateAddDialog

class TemplateEditDialog(TemplateAddDialog):
	"""
	This class implements a dialog that allows users to edit template
	in the template database. The class defines the default properties
	and behavior of the dialog.
	"""

	def __init__(self, template_editor):
		"""
		Initialize the dialog.

		@param self: Reference to the TemplateEditDialog instance.
		@type self: A TemplateEditDialog object.

		@param template_editor: The text editor's template editor.
		@type template_editor: A ScribesTemplateEditor object.
		"""
		TemplateAddDialog.__init__(self, template_editor)
		from internationalization import msg0313
		self.set_property("title", msg0313)
		self.connect("show-dialog", self.__dialog_show_dialog_cb)

	def dialog_clicked_cb(self, button):
		"""
		Handles callback when the "clicked" signal is emitted.

		@param self: Reference to the TemplateEditDialog instance.
		@type self: A TemplateEditDialog object.

		@param button: The dialog's add button.
		@type button: A gtk.Button object.

		@return: True to propagate signals to parent widgets.
		@type: A Boolean Object.
		"""
		self.template_editor.remove_template_from_database()
		TemplateAddDialog.dialog_clicked_cb(self, button)
		return True

	def __dialog_show_dialog_cb(self, dialog):
		"""
		Handles callback when the "show-dialog" signal is emitted.

		@param self: Reference to the TemplateEditDialog instance.
		@type self: A TemplateEditDialog object.

		@param dialog: Reference to the TemplateEditDialog
		@type dialog: A TemplateEditDialog object.
		"""
		language_selection = self.language_view.get_selection()
		model, iterator = language_selection.get_selected()
		language_id = model.get_value(iterator, 1)
		description_selection = self.description_view.get_selection()
		model, paths = description_selection.get_selected_rows()
		iterator = model.get_iter(paths[0])
		trigger = model.get_value(iterator, 0)
		template_key = language_id + trigger
		from template_metadata import open_template_database
		from template_metadata import close_template_database
		database = open_template_database()
		for key, value in database.items():
			if key == template_key:
				description = value[0]
				template = value[1]
				self.dialog_editor.get_buffer().set_text(template)
				self.description_entry.set_text(description)
				self.name_entry.set_text(trigger)
				self.name_entry.grab_focus()
				break
		close_template_database(database)
		return
