# -*- coding: utf-8 -*-
# Copyright © 2005 Lateef Alabi-Oki
#
# This file is part of Scribes.
#
# Scribes is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Scribes is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Scribes; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

"""
This module documents a class that creates the import button for the text
editor's template editor.

@author: Lateef Alabi-Oki
@organization: The Scribes Project
@copyright: Copyright © 2005 Lateef Alabi-Oki
@license: GNU GPLv2 or Later
@contact: mystilleef@gmail.com
"""

from gtk import Button

class TemplateEditorImportButton(Button):
	"""
	This class creates the import button for the template editor. Pressing
	the button activates an open dialog that allows you to import templates
	into the template editor. The class defines the default properties and
	behavior of the add button.
	"""

	def __init__(self, template_editor):
		"""
		Initialize the button.

		@param self: Reference to the TemplateEditorImportButton instance.
		@type self: A TemplateEditorImportButton object.

		@param template_editor: The text editor's template editor.
		@type template_editor: A ScribesTemplateEditor object.
		"""
		Button.__init__(self)
		self.__init_attributes(template_editor)
		self.__create_icon_and_text()
		self.connect("clicked", self.__button_clicked_cb)

	def __init_attributes(self, template_editor):
		"""
		Initialize the button's attributes.

		@param self: Reference to the TemplateEditorImportButton instance.
		@type self: A TemplateEditorImportButton object.

		@param template_editor: The text editor's template editor.
		@type template_editor: A ScribesTemplateEditor object.
		"""
		self.template_editor = template_editor
		self.dialog = None
		return

	def __create_icon_and_text(self):
		"""
		Create the text and icon for the import button.

		@param self: Reference to the TemplateEditorImportButton instance.
		@type self: A TemplateEditorImportButton object.
		"""
		from utils import create_button
		from gtk import STOCK_REDO
		from internationalization import msg0420
		hbox = create_button(STOCK_REDO, msg0420)
		self.add(hbox)
		return

	def __button_clicked_cb(self, button):
		"""
		Handles callback when the "clicked" signal is emitted.

		@param self: Reference to the TemplateEditorImportButton instance.
		@type self: A TemplateEditorImportButton object.

		@param button: Reference to the TemplateEditorImportButton.
		@type button: A TemplateEditorImportButton object.

		@return: True to propagate signals to parent widgets.
		@type: A Boolean Object.
		"""
		try:
			self.dialog.show_dialog()
		except:
			from importdialog import ImportDialog
			self.dialog = ImportDialog(self)
			self.dialog.show_dialog()
		return True
