# -*- coding: utf-8 -*-
# Copyright © 2005 Lateef Alabi-Oki
#
# This file is part of Scribes.
#
# Scribes is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Scribes is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Scribes; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

"""
This module exposes a class that creates the container for the editor's view.

@author: Lateef Alabi-Oki
@organization: The Scribes Project
@copyright: Copyright © 2005 Lateef Alabi-Oki
@license: GNU GPLv2 or Later
@contact: mystilleef@gmail.com
"""

from gtk import HBox

class ScribesViewContainer(HBox):
	"""
	This class creates the view container object for the text editor. The object
	houses the text editor's viewing area.
	"""

	def __init__(self, editor):
		"""
		Initialize the text editor's viewing area's container and set its
		default state and properties.

		@param self: Reference to the ScribesViewContainer instance.
		@type self: A ScribesViewContainer object.

		@param editor: Reference to the text editor.
		@type editor: An Editor object.
		"""
		from utils import response
		response()
		HBox.__init__(self)
		self.__init_attributes(editor)
		self.__set_properties()
		self.editor.connect("show-dialog", self.__viewcontainer_show_dialog_cb)
		self.editor.connect("hide-dialog", self.__viewcontainer_hide_dialog_cb)
#		self.editor.connect("show-bar", self.__viewcontainer_show_bar_cb)
#		self.editor.connect("hide-bar", self.__viewcontainer_hide_bar_cb)
		self.resize_children()

	def __init_attributes(self, editor):
		"""
		Initialize the container's attributes.

		@param self: Reference to the ScribesViewContainer instance.
		@type self: A ScribesViewContainer object.

		@param editor: Reference to the text editor.
		@type editor: An Editor object.
		"""
		self.editor = editor
		self.bar_is_visible = False
		return

	def __set_properties(self):
		"""
		Set the container's properties.

		@param self: Reference to the ScribesViewContainer instance.
		@type self: A ScribesViewContainer object.
		"""
		from gtk import RESIZE_PARENT
		self.set_property("resize-mode", RESIZE_PARENT)
		self.set_property("name", "scribesviewcontainer")
		return

	def __viewcontainer_show_dialog_cb(self, editor, dialog):
		"""
		Handles callback when the "show-dialog" signal is emitted.

		@param self: Reference to the ScribesToolbarContainer instance.
		@type self: A ScribesToolbarContainer object.

		@param editor: Reference to the text editor.
		@type editor: An Editor object.
		"""
		self.set_property("sensitive", False)
		return

	def __viewcontainer_hide_dialog_cb(self, editor, dialog):
		"""
		Handles callback when the "hide-dialog" signal is emitted.

		@param self: Reference to the ScribesToolbarContainer instance.
		@type self: A ScribesToolbarContainer object.

		@param editor: Reference to the text editor.
		@type editor: An Editor object.
		"""
		self.set_property("sensitive", True)
		return

	def __viewcontainer_show_bar_cb(self, editor, bar):
		"""
		Handles callback when the "show-bar" signal is emitted.

		@param self: Reference to the ScribesViewContainer instance.
		@type self: A ScribesViewContainer object.

		@param editor: Reference to the text editor.
		@type editor: An Editor object.

		@param bar: The text editor's bar.
		@type bar: A ScribesBar object.
		"""
		self.set_property("sensitive", False)
		self.bar_is_visible = True
		return

	def __viewcontainer_hide_bar_cb(self, editor, bar):
		"""
		Handles callback when the "hide-bar" signal is emitted.

		@param self: Reference to the ScribesViewContainer instance.
		@type self: A ScribesViewContainer object.

		@param editor: Reference to the text editor.
		@type editor: An Editor object.

		@param bar: The text editor's bar.
		@type bar: A ScribesBar object.
		"""
		self.set_property("sensitive", True)
		self.bar_is_visible = False
		return
